@@ -16,12 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sample-mozilla.c 1635 2007-11-04 01:34:53Z cyrilbois $
+ *  $Id: sample-mozilla.c 1730 2008-05-18 21:51:27Z chpe $
  */
 
 #include "config.h"
 
 #include "ephy-sample2-extension.h"
+#include "mozilla-sample.h"
 #include "ephy-debug.h"
 
 #include <gmodule.h>
@@ -34,6 +35,9 @@ register_module (GTypeModule *module)
 {
 	LOG ("Registering EphySample2Extension");
 
+        if (!mozilla_glue_startup ())
+              return 0;
+
 #ifdef ENABLE_NLS
 	/* Initialise the i18n stuff */
 	bindtextdomain (GETTEXT_PACKAGE, EPHY_EXTENSIONS_LOCALEDIR);
